'''
Manage schedule condition of the HDInsight cluster which enabled Schedule-based Autoscale.
'''
from .... pyaz_utils import _call_az

def create(cluster_name, days, resource_group, time, workernode_count, no_wait=None):
    '''
    Add a new schedule condition.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - days -- A space-delimited list of schedule day.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - time -- The 24-hour time in the form xx:xx in days.
    - workernode_count -- The schedule workernode count.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az hdinsight autoscale condition create", locals())


def update(cluster_name, index, resource_group, days=None, no_wait=None, time=None, workernode_count=None):
    '''
    Update a schedule condition.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - index -- The schedule condition index which starts with 0.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - days -- A space-delimited list of schedule day.
    - no_wait -- Do not wait for the long-running operation to finish.
    - time -- The 24-hour time in the form xx:xx in days.
    - workernode_count -- The schedule workernode count.
    '''
    return _call_az("az hdinsight autoscale condition update", locals())


def list(cluster_name, resource_group):
    '''
    List all schedule conditions.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az hdinsight autoscale condition list", locals())


def delete(cluster_name, index, resource_group, no_wait=None, yes=None):
    '''
    Delete schedule condition.

    Required Parameters:
    - cluster_name -- The name of the cluster.
    - index -- The Space-separated list of condition indices which starts with 0 to delete.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az hdinsight autoscale condition delete", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until an operation is complete.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az hdinsight autoscale condition wait", locals())




'''
Manage the Azure Network Watcher.
'''
from ... pyaz_utils import _call_az
from . import connection_monitor, flow_log, packet_capture, troubleshooting


def configure(locations, enabled=None, resource_group=None, tags=None):
    '''
    Configure the Network Watcher service for different regions.

    Required Parameters:
    - locations -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.

    Optional Parameters:
    - enabled -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az network watcher configure", locals())


def list():
    '''
    List Network Watchers.
    '''
    return _call_az("az network watcher list", locals())


def test_ip_flow(direction, local, protocol, remote, vm, nic=None, resource_group=None):
    '''
    Test IP flow to/from a VM given the currently configured network security group rules.

    Required Parameters:
    - direction -- None
    - local -- None
    - protocol -- None
    - remote -- None
    - vm -- Name or ID of the VM to target. If the name of the VM is provided, the --resource-group is required.

    Optional Parameters:
    - nic -- Name or ID of the NIC resource to test. If the VM has multiple NICs and IP forwarding is enabled on any of them, this parameter is required.
    - resource_group -- Name of the resource group the target VM is in.
    '''
    return _call_az("az network watcher test-ip-flow", locals())


def test_connectivity(source_resource, dest_address=None, dest_port=None, dest_resource=None, headers=None, method=None, protocol=None, resource_group=None, source_port=None, valid_status_codes=None):
    '''
    Test if a connection can be established between a Virtual Machine and a given endpoint.

    Required Parameters:
    - source_resource -- None

    Optional Parameters:
    - dest_address -- None
    - dest_port -- None
    - dest_resource -- None
    - headers -- Space-separated list of headers in `KEY=VALUE` format.
    - method -- HTTP method to use.
    - protocol -- Protocol to test on.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source_port -- None
    - valid_status_codes -- Space-separated list of HTTP status codes considered valid.
    '''
    return _call_az("az network watcher test-connectivity", locals())


def show_next_hop(dest_ip, resource_group, source_ip, vm, nic=None):
    '''
    Get information on the 'next hop' of a VM.

    Required Parameters:
    - dest_ip -- Destination IPv4 address.
    - resource_group -- Name of the resource group the target VM is in.
    - source_ip -- Source IPv4 address.
    - vm -- Name or ID of the VM to target. If the name of the VM is provided, the --resource-group is required.

    Optional Parameters:
    - nic -- Name or ID of the NIC resource to test. If the VM has multiple NICs and IP forwarding is enabled on any of them, this parameter is required.
    '''
    return _call_az("az network watcher show-next-hop", locals())


def show_security_group_view(resource_group, vm):
    '''
    Get detailed security information on a VM for the currently configured network security group.

    Required Parameters:
    - resource_group -- Name of the resource group the target VM is in.
    - vm -- Name or ID of the VM to target. If the name of the VM is provided, the --resource-group is required.
    '''
    return _call_az("az network watcher show-security-group-view", locals())


def show_topology(location=None, resource_group=None, subnet=None, vnet=None):
    '''
    Get the network topology of a resource group, virtual network or subnet.

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - resource_group -- None
    - subnet -- Name or ID of the subnet to target. If name is used, --vnet NAME must also be supplied.
    - vnet -- Name or ID of the virtual network to target.
    '''
    return _call_az("az network watcher show-topology", locals())


def run_configuration_diagnostic(resource, destination=None, direction=None, parent=None, port=None, protocol=None, queries=None, resource_group=None, resource_type=None, source=None):
    '''
    Run a configuration diagnostic on a target resource.

    Required Parameters:
    - resource -- Name or ID of the target resource to diagnose. If an ID is given, other resource arguments should not be given.

    Optional Parameters:
    - destination -- Traffic destination. Accepted values are '*', IP address/CIDR, or service tag.
    - direction -- Direction of the traffic.
    - parent -- The parent path. (ex: virtualMachineScaleSets/vmss1)
    - port -- Traffic destination port. Accepted values are '*', port number (3389) or port range (80-100).
    - protocol -- Protocol to be verified on.
    - queries -- JSON list of queries to use. Use `@{path}` to load from a file.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- The resource type
    - source -- Traffic source. Accepted values are '*', IP address/CIDR, or service tag.
    '''
    return _call_az("az network watcher run-configuration-diagnostic", locals())




from ... pyaz_utils import _call_az
from . import policy, policy_definition


def list(location):
    '''
    

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az network service-endpoint list", locals())




'''
Manage geo-replicated regions of Azure Container Registries.
'''
from ... pyaz_utils import _call_az

def list(registry, resource_group=None):
    '''
    List all of the regions for a geo-replicated Azure Container Registry.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr replication list", locals())


def create(location, registry, name=None, region_endpoint_enabled=None, resource_group=None, tags=None, zone_redundancy=None):
    '''
    Create a replicated region for an Azure Container Registry.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - name -- The name of the replication. Default to the location name.
    - region_endpoint_enabled -- Allow routing to this replication. Requests will not be routed to a disabled replication. Data syncing will continue regardless of the region endpoint status. Default: true.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - zone_redundancy -- Indicates whether or not zone redundancy should be enabled for this registry or replication. For more information, such as supported locations, please visit https://aka.ms/acr/az. Zone-redundancy cannot be updated. Defaults to 'Disabled'.
    '''
    return _call_az("az acr replication create", locals())


def delete(name, registry, resource_group=None):
    '''
    Delete a replicated region from an Azure Container Registry.

    Required Parameters:
    - name -- The name of the replication.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr replication delete", locals())


def show(name, registry, resource_group=None):
    '''
    Get the details of a replicated region.

    Required Parameters:
    - name -- The name of the replication.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr replication show", locals())


def update(name, registry, add=None, force_string=None, region_endpoint_enabled=None, remove=None, resource_group=None, set=None, tags=None):
    '''
    Updates a replication.

    Required Parameters:
    - name -- The name of the replication.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - region_endpoint_enabled -- Allow routing to this replication. Requests will not be routed to a disabled replication. Data syncing will continue regardless of the region endpoint status.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az acr replication update", locals())




'''
Manage Azure Cosmos DB SQL role definitions.
'''
from ..... pyaz_utils import _call_az

def create(account_name, body, resource_group, no_wait=None):
    '''
    Create a SQL role definition under an Azure Cosmos DB account.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - body -- Role Definition body with Id (Optional for create), DataActions or Permissions, Type (Default is CustomRole), and AssignableScopes.  You can enter it as a string or as a file, e.g., --body @rdbody-file.json or --body "{ \"Id\": \"be79875a-2cc4-40d5-8958-566017875b39\", \"RoleName\": \"My Read Write Role\", \"Type\": \"CustomRole\", \"AssignableScopes\": [ \"/\" ], \"DataActions\": [ \"Microsoft.DocumentDB/databaseAccounts/sqlDatabases/containers/items/create\", \"Microsoft.DocumentDB/databaseAccounts/sqlDatabases/containers/items/read\" ]}"

    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az cosmosdb sql role definition create", locals())


def update(account_name, body, resource_group, no_wait=None):
    '''
    Update a SQL role definition under an Azure Cosmos DB account.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - body -- Role Definition body with Id (Optional for create), DataActions or Permissions, Type (Default is CustomRole), and AssignableScopes.  You can enter it as a string or as a file, e.g., --body @rdbody-file.json or --body "{ \"Id\": \"be79875a-2cc4-40d5-8958-566017875b39\", \"RoleName\": \"My Read Write Role\", \"Type\": \"CustomRole\", \"AssignableScopes\": [ \"/\" ], \"DataActions\": [ \"Microsoft.DocumentDB/databaseAccounts/sqlDatabases/containers/items/create\", \"Microsoft.DocumentDB/databaseAccounts/sqlDatabases/containers/items/read\" ]}"

    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az cosmosdb sql role definition update", locals())


def exists(account_name, id, resource_group):
    '''
    Check if an Azure Cosmos DB role definition exists.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - id -- Unique ID for the Role Definition.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb sql role definition exists", locals())


def list(account_name, resource_group):
    '''
    List all SQL role definitions under an Azure Cosmos DB account.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb sql role definition list", locals())


def show(account_name, id, resource_group):
    '''
    Show the properties of a SQL role definition under an Azure Cosmos DB account.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - id -- Unique ID for the Role Definition.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb sql role definition show", locals())


def delete(account_name, id, resource_group, no_wait=None, yes=None):
    '''
    Delete a SQL role definition under an Azure Cosmos DB account.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - id -- Unique ID for the Role Definition.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cosmosdb sql role definition delete", locals())


def wait(account_name, id, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Poll on a SQL role definition until a specific condition is met.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - id -- Unique ID for the Role Definition.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az cosmosdb sql role definition wait", locals())




from ... pyaz_utils import _call_az

def create(end_ip, name, resource_group, rule_name, start_ip):
    '''
    Create a redis cache firewall rule.

    Required Parameters:
    - end_ip -- Highest IP address included in the range.
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- The name of the firewall rule.
    - start_ip -- Lowest IP address included in the range.
    '''
    return _call_az("az redis firewall-rules create", locals())


def update(end_ip, name, resource_group, rule_name, start_ip):
    '''
    Update a redis cache firewall rule.

    Required Parameters:
    - end_ip -- Highest IP address included in the range.
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- The name of the firewall rule.
    - start_ip -- Lowest IP address included in the range.
    '''
    return _call_az("az redis firewall-rules update", locals())


def delete(name, resource_group, rule_name):
    '''
    

    Required Parameters:
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- The name of the firewall rule.
    '''
    return _call_az("az redis firewall-rules delete", locals())


def show(name, resource_group, rule_name):
    '''
    

    Required Parameters:
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - rule_name -- The name of the firewall rule.
    '''
    return _call_az("az redis firewall-rules show", locals())


def list(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Name of the Redis cache.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az redis firewall-rules list", locals())




'''
List reservation details.
'''
from .... pyaz_utils import _call_az

def list(end_date, reservation_order_id, start_date, reservation_id=None):
    '''
    List the details of a reservation by order id or reservation id.

    Required Parameters:
    - end_date -- End date (YYYY-MM-DD in UTC). Only needed for daily grain and if specified, also requires --start-date.
    - reservation_order_id -- Reservation order id.
    - start_date -- Start date (YYYY-MM-DD in UTC). Only needed for daily grain and if specified, also requires --end-date.

    Optional Parameters:
    - reservation_id -- Reservation id.
    '''
    return _call_az("az consumption reservation detail list", locals())




'''
Manage Azure API Management API Revision.
'''
from .... pyaz_utils import _call_az

def list(api_id, resource_group, service_name):
    '''
    Lists all revisions of an API.

    Required Parameters:
    - api_id -- API identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.
    '''
    return _call_az("az apim api revision list", locals())


def create(api_id, api_revision, resource_group, service_name, api_revision_description=None):
    '''
    Create API revision.

    Required Parameters:
    - api_id -- API identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - api_revision -- Describes the Revision of the Api.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.

    Optional Parameters:
    - api_revision_description -- Description of the Api Revision.
    '''
    return _call_az("az apim api revision create", locals())




'''
View security alerts.
'''
from ... pyaz_utils import _call_az

def list(location=None, resource_group=None):
    '''
    List security alerts.

    Optional Parameters:
    - location -- location of the resource
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az security alert list", locals())


def show(location, name, resource_group=None):
    '''
    Shows a security alert.

    Required Parameters:
    - location -- location of the resource
    - name -- name of the resource to be fetched

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az security alert show", locals())


def update(location, name, status, resource_group=None):
    '''
    Updates a security alert status.

    Required Parameters:
    - location -- location of the resource
    - name -- name of the resource to be fetched
    - status -- target status of the alert. possible values are "dismiss" and "activate"

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az security alert update", locals())




from ... pyaz_utils import _call_az
from . import client_certificate


def list(resource_group=None):
    '''
    List managed clusters.

    Optional Parameters:
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-cluster list", locals())


def delete(cluster_name, resource_group):
    '''
    Delete a managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-cluster delete", locals())


def show(cluster_name, resource_group):
    '''
    Show the properties of an Azure Service Fabric managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-cluster show", locals())


def create(admin_password, cluster_name, resource_group, admin_user_name=None, client_cert_common_name=None, client_cert_is_admin=None, client_cert_issuer_thumbprint=None, client_cert_thumbprint=None, client_connection_port=None, cluster_code_version=None, cluster_upgrade_cadence=None, cluster_upgrade_mode=None, dns_name=None, gateway_connection_port=None, location=None, sku=None, tags=None):
    '''
    Delete a managed cluster.

    Required Parameters:
    - admin_password -- Admin password used for the virtual machines.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - admin_user_name -- Admin user used for the virtual machines.
    - client_cert_common_name -- Client certificate common name.
    - client_cert_is_admin -- Client authentication type.
    - client_cert_issuer_thumbprint -- Space-separated list of issuer thumbprints.
    - client_cert_thumbprint -- Client certificate thumbprint.
    - client_connection_port -- Port used for client connections to the cluster.
    - cluster_code_version -- Cluster service fabric code version. Only use if upgrade mode is Manual.
    - cluster_upgrade_cadence -- The upgrade mode of the cluster when new Service Fabric runtime version is available Wave0: Cluster upgrade starts immediately after a new version is rolled out. Recommended for Test/Dev clusters.Wave1: Cluster upgrade starts 7 days after a new version is rolled out. Recommended for Pre-prod clusters.Wave2: Cluster upgrade starts 14 days after a new version is rolled out. Recommended for Production clusters.
    - cluster_upgrade_mode -- The upgrade mode of the cluster when new Service Fabric runtime version is available Automatic: The cluster will be automatically upgraded to the latest Service Fabric runtime version, upgrade_cadence will determine when the upgrade starts after the new version becomes available.Manual: The cluster will not be automatically upgraded to the latest Service Fabric runtime version. The cluster is upgraded by setting the code_version property in the cluster resource.
    - dns_name -- Cluster's dns name.
    - gateway_connection_port -- Port used for http connections to the cluster.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - sku -- Cluster's Sku, the options are Basic: it will have a minimum of 3 seed nodes and only allows 1 node type and Standard: it will have a minimum of 5 seed nodes and allows multiple node types.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sf managed-cluster create", locals())


def update(cluster_name, resource_group, client_connection_port=None, dns_name=None, gateway_connection_port=None, tags=None):
    '''
    Update a managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - client_connection_port -- Port used for client connections to the cluster.
    - dns_name -- Cluster's dns name
    - gateway_connection_port -- Port used for http connections to the cluster.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sf managed-cluster update", locals())




'''
Manage resource policy remediations.
'''
from ... pyaz_utils import _call_az
from . import deployment


def show(name, management_group=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Show a resource policy remediation.

    Required Parameters:
    - name -- Name of the remediation.

    Optional Parameters:
    - management_group -- Name of management group.
    - namespace -- Provider namespace (Ex: Microsoft.Provider).
    - parent -- The parent path (Ex: resourceTypeA/nameA/resourceTypeB/nameB).
    - resource -- Resource ID or resource name. If a name is given, please provide the resource group and other relevant resource id arguments.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- Resource type (Ex: resourceTypeC).
    '''
    return _call_az("az policy remediation show", locals())


def list(management_group=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    List resource policy remediations.

    Optional Parameters:
    - management_group -- Name of management group.
    - namespace -- Provider namespace (Ex: Microsoft.Provider).
    - parent -- The parent path (Ex: resourceTypeA/nameA/resourceTypeB/nameB).
    - resource -- Resource ID or resource name. If a name is given, please provide the resource group and other relevant resource id arguments.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- Resource type (Ex: resourceTypeC).
    '''
    return _call_az("az policy remediation list", locals())


def delete(name, management_group=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Delete a resource policy remediation.

    Required Parameters:
    - name -- Name of the remediation.

    Optional Parameters:
    - management_group -- Name of management group.
    - namespace -- Provider namespace (Ex: Microsoft.Provider).
    - parent -- The parent path (Ex: resourceTypeA/nameA/resourceTypeB/nameB).
    - resource -- Resource ID or resource name. If a name is given, please provide the resource group and other relevant resource id arguments.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- Resource type (Ex: resourceTypeC).
    '''
    return _call_az("az policy remediation delete", locals())


def cancel(name, management_group=None, namespace=None, parent=None, resource=None, resource_group=None, resource_type=None):
    '''
    Cancel a resource policy remediation.

    Required Parameters:
    - name -- Name of the remediation.

    Optional Parameters:
    - management_group -- Name of management group.
    - namespace -- Provider namespace (Ex: Microsoft.Provider).
    - parent -- The parent path (Ex: resourceTypeA/nameA/resourceTypeB/nameB).
    - resource -- Resource ID or resource name. If a name is given, please provide the resource group and other relevant resource id arguments.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- Resource type (Ex: resourceTypeC).
    '''
    return _call_az("az policy remediation cancel", locals())


def create(name, policy_assignment, definition_reference_id=None, location_filters=None, management_group=None, namespace=None, parent=None, resource=None, resource_discovery_mode=None, resource_group=None, resource_type=None):
    '''
    Create a resource policy remediation.

    Required Parameters:
    - name -- Name of the remediation.
    - policy_assignment -- Name or resource ID of the policy assignment.

    Optional Parameters:
    - definition_reference_id -- Policy definition reference ID inside the policy set definition. Only required when the policy assignment is assigning a policy set definition.
    - location_filters -- Space separated list of resource locations that should be remediated (Ex: centralus westeurope).
    - management_group -- Name of management group.
    - namespace -- Provider namespace (Ex: Microsoft.Provider).
    - parent -- The parent path (Ex: resourceTypeA/nameA/resourceTypeB/nameB).
    - resource -- Resource ID or resource name. If a name is given, please provide the resource group and other relevant resource id arguments.
    - resource_discovery_mode -- The way resources to remediate are discovered. Defaults to ExistingNonCompliant if not specified.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- Resource type (Ex: resourceTypeC).
    '''
    return _call_az("az policy remediation create", locals())




'''
Manage Azure Managed Applications.
'''
from ... pyaz_utils import _call_az

def create(authorizations, description, display_name, lock_level, name, resource_group, create_ui_definition=None, location=None, main_template=None, package_file_uri=None, tags=None):
    '''
    Create a managed application definition.

    Required Parameters:
    - authorizations -- space-separated authorization pairs in a format of `<principalId>:<roleDefinitionId>`
    - description -- the managed application definition description
    - display_name -- the managed application definition display name
    - lock_level -- The type of lock restriction.
    - name -- the managed application definition name
    - resource_group -- the resource group of the managed application definition

    Optional Parameters:
    - create_ui_definition -- JSON formatted string or a path to a file with such content
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - main_template -- JSON formatted string or a path to a file with such content
    - package_file_uri -- the managed application definition package file uri
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az managedapp definition create", locals())


def update(authorizations, description, display_name, lock_level, name, resource_group, create_ui_definition=None, location=None, main_template=None, package_file_uri=None, tags=None):
    '''
    Update a managed application definition.

    Required Parameters:
    - authorizations -- space-separated authorization pairs in a format of `<principalId>:<roleDefinitionId>`
    - description -- the managed application definition description
    - display_name -- the managed application definition display name
    - lock_level -- The type of lock restriction.
    - name -- the managed application definition name
    - resource_group -- the resource group of the managed application definition

    Optional Parameters:
    - create_ui_definition -- JSON formatted string or a path to a file with such content
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - main_template -- JSON formatted string or a path to a file with such content
    - package_file_uri -- the managed application definition package file uri
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az managedapp definition update", locals())


def delete(name, resource_group):
    '''
    Delete a managed application definition.

    Required Parameters:
    - name -- The name of the managed application definition to delete.
    - resource_group -- the resource group of the managed application definition
    '''
    return _call_az("az managedapp definition delete", locals())


def show(name=None, resource_group=None):
    '''
    

    Optional Parameters:
    - name -- the managed application definition name
    - resource_group -- the resource group of the managed application definition
    '''
    return _call_az("az managedapp definition show", locals())


def list(resource_group):
    '''
    List managed application definitions.

    Required Parameters:
    - resource_group -- the resource group of the managed application definition
    '''
    return _call_az("az managedapp definition list", locals())




'''
Manage resource policy exemptions.
'''
from ... pyaz_utils import _call_az

def create(name, description=None, display_name=None, exemption_category=None, expires_on=None, metadata=None, policy_assignment=None, policy_definition_reference_ids=None, resource_group=None, scope=None):
    '''
    Create a policy exemption.

    Required Parameters:
    - name -- Name of the new policy exemption.

    Optional Parameters:
    - description -- Description of policy exemption.
    - display_name -- Display name of the policy exemption.
    - exemption_category -- The policy exemption category of the policy exemption
    - expires_on -- The expiration date and time (in UTC ISO 8601 format yyyy-MM-ddTHH:mm:ssZ) of the policy exemption.
    - metadata -- Metadata in space-separated key=value pairs.
    - policy_assignment -- The referenced policy assignment Id for the policy exemption.
    - policy_definition_reference_ids -- The policy definition reference ids to exempt in the initiative (policy set).
    - resource_group -- the resource group where the policy will be applied
    - scope -- Scope to which this policy exemption applies.
    '''
    return _call_az("az policy exemption create", locals())


def delete(name, resource_group=None, scope=None):
    '''
    Delete a policy exemption.

    Required Parameters:
    - name -- Name of the policy exemption.

    Optional Parameters:
    - resource_group -- the resource group where the policy will be applied
    - scope -- Scope to which this policy exemption applies.
    '''
    return _call_az("az policy exemption delete", locals())


def list(disable_scope_strict_match=None, resource_group=None, scope=None):
    '''
    List policy exemptions.

    Optional Parameters:
    - disable_scope_strict_match -- Include policy exemptions either inherited from parent scope or at child scope.
    - resource_group -- the resource group where the policy will be applied
    - scope -- Scope to which this policy exemption applies.
    '''
    return _call_az("az policy exemption list", locals())


def show(name, resource_group=None, scope=None):
    '''
    Show a policy exemption.

    Required Parameters:
    - name -- Name of the policy exemption.

    Optional Parameters:
    - resource_group -- the resource group where the policy will be applied
    - scope -- Scope to which this policy exemption applies.
    '''
    return _call_az("az policy exemption show", locals())


def update(name, description=None, display_name=None, exemption_category=None, expires_on=None, metadata=None, policy_definition_reference_ids=None, resource_group=None, scope=None):
    '''
    Update a policy exemption.

    Required Parameters:
    - name -- Name of the policy exemption.

    Optional Parameters:
    - description -- Description of policy exemption.
    - display_name -- Display name of the policy exemption.
    - exemption_category -- The policy exemption category of the policy exemption
    - expires_on -- The expiration date and time (in UTC ISO 8601 format yyyy-MM-ddTHH:mm:ssZ) of the policy exemption.
    - metadata -- Metadata in space-separated key=value pairs.
    - policy_definition_reference_ids -- The policy definition reference ids to exempt in the initiative (policy set).
    - resource_group -- the resource group where the policy will be applied
    - scope -- Scope to which this policy exemption applies.
    '''
    return _call_az("az policy exemption update", locals())




'''
Manage Batch account keys.
'''
from .... pyaz_utils import _call_az

def list(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Name of the Batch account.
    - resource_group -- Name of the resource group
    '''
    return _call_az("az batch account keys list", locals())


def renew(key_name=None, name=None, resource_group=None):
    '''
    Renew keys for a Batch account.

    Optional Parameters:
    - key_name -- Name of the batch account key.
    - name -- Name of the batch account to show. If not specified will display currently set account.
    - resource_group -- Name of the resource group. If not specified will display currently set account.
    '''
    return _call_az("az batch account keys renew", locals())




'''
Manage partner registrations.
'''
from .... pyaz_utils import _call_az

def show(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Name of the partner registration.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid partner registration show", locals())


def delete(name, resource_group, yes=None):
    '''
    

    Required Parameters:
    - name -- Name of the partner registration.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az eventgrid partner registration delete", locals())


def list(odata_query=None, resource_group=None):
    '''
    List all partner registrations in specific resource group or all under the specified azure subscription.

    Optional Parameters:
    - odata_query -- The OData query used for filtering the list results. Filtering is currently allowed on the Name property only. The supported operations include: CONTAINS, eq (for equal), ne (for not equal), AND, OR and NOT.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid partner registration list", locals())


def create(name, partner_name, resource_group, resource_type_name, authorized_subscription_ids=None, customer_service_extension=None, customer_service_number=None, customer_service_uri=None, description=None, display_name=None, logo_uri=None, long_description=None, setup_uri=None, tags=None):
    '''
    Create a new partner registration.

    Required Parameters:
    - name -- Name of the partner registration.
    - partner_name -- Official name of the partner.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type_name -- Name of the partner topic resource type. This name should be unique among all partner topic types names.

    Optional Parameters:
    - authorized_subscription_ids -- A space-separated list of Azure subscription Ids that are authorized to create a partner namespace associated with this partner registration. This is an optional property. Creating partner namespaces is always permitted under the same Azure subscription as the one used for creating the partner registration.
    - customer_service_extension -- The extension of the customer service number of the publisher. Only digits are allowed and number of digits should not exceed 10.
    - customer_service_number -- The customer service number of the publisher. The expected phone format should start with a '+' sign followed by the country code. The remaining digits are then followed. Only digits and spaces are allowed and its length cannot exceed 16 digits including country code. Examples of valid phone numbers are: +1 515 123 4567 and +966 7 5115 2471. Examples of invalid phone numbers are: +1 (515) 123-4567, 1 515 123 4567 and +966 121 5115 24 7 551 1234 43.
    - customer_service_uri -- The customer service URI of the publisher.
    - description -- Description of the partner topic type.
    - display_name -- Display name for the partner topic type.
    - logo_uri -- URI of the partner logo.
    - long_description -- Description of the custom scenarios and integration. Length of this description should not exceed 2048 characters
    - setup_uri -- URI of the partner website that can be used by Azure customers to setup Event Grid integration on an event source.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az eventgrid partner registration create", locals())




from .... pyaz_utils import _call_az

def list(kusto_pool_name, resource_group, workspace_name):
    '''
    Returns the list of attached database configurations of the given Kusto Pool.

    Required Parameters:
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace
    '''
    return _call_az("az synapse kusto attached-database-configuration list", locals())


def show(attached_database_configuration_name, kusto_pool_name, resource_group, workspace_name):
    '''
    Returns an attached database configuration.

    Required Parameters:
    - attached_database_configuration_name -- The name of the attached database configuration.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace
    '''
    return _call_az("az synapse kusto attached-database-configuration show", locals())


def create(attached_database_configuration_name, kusto_pool_name, resource_group, workspace_name, database_name=None, default_principals_modification_kind=None, kusto_pool_resource_id=None, location=None, no_wait=None, table_level_sharing_properties=None):
    '''
    Create an attached database configuration.

    Required Parameters:
    - attached_database_configuration_name -- The name of the attached database configuration.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - database_name -- The name of the database which you would like to attach, use * if you want to follow all current and future databases.
    - default_principals_modification_kind -- The default principals modification kind
    - kusto_pool_resource_id -- The resource id of the kusto pool where the databases you would like to attach reside.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - table_level_sharing_properties -- Table level sharing specifications
    '''
    return _call_az("az synapse kusto attached-database-configuration create", locals())


def update(attached_database_configuration_name, kusto_pool_name, resource_group, workspace_name, add=None, database_name=None, default_principals_modification_kind=None, force_string=None, kusto_pool_resource_id=None, location=None, no_wait=None, remove=None, set=None, table_level_sharing_properties=None):
    '''
    Update an attached database configuration.

    Required Parameters:
    - attached_database_configuration_name -- The name of the attached database configuration.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - database_name -- The name of the database which you would like to attach, use * if you want to follow all current and future databases.
    - default_principals_modification_kind -- The default principals modification kind
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - kusto_pool_resource_id -- The resource id of the kusto pool where the databases you would like to attach reside.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - table_level_sharing_properties -- Table level sharing specifications
    '''
    return _call_az("az synapse kusto attached-database-configuration update", locals())


def delete(attached_database_configuration_name, kusto_pool_name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Deletes the attached database configuration with the given name.

    Required Parameters:
    - attached_database_configuration_name -- The name of the attached database configuration.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse kusto attached-database-configuration delete", locals())


def wait(attached_database_configuration_name, kusto_pool_name, resource_group, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the synapse kusto attached-database-configuration is met.

    Required Parameters:
    - attached_database_configuration_name -- The name of the attached database configuration.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse kusto attached-database-configuration wait", locals())




from ... pyaz_utils import _call_az

def list(location=None, resource_group=None):
    '''
    List your Just in Time network access policies.

    Optional Parameters:
    - location -- location of the resource
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az security jit-policy list", locals())


def show(location, name, resource_group):
    '''
    Shows a Just in Time network access policy.

    Required Parameters:
    - location -- location of the resource
    - name -- name of the resource to be fetched
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az security jit-policy show", locals())




from .... pyaz_utils import _call_az

def create(message, name, policy_definition_reference_id=None, resource_group=None, scope=None):
    '''
    Add a non-compliance message to a policy assignment.

    Required Parameters:
    - message -- Message that will be shown when a resource is denied by policy or evaluation details are inspected.
    - name -- Name of the policy assignment.

    Optional Parameters:
    - policy_definition_reference_id -- Policy definition reference ID within the assigned initiative (policy set) that the message applies to.
    - resource_group -- the resource group where the policy will be applied
    - scope -- Scope to which this policy assignment applies.
    '''
    return _call_az("az policy assignment non-compliance-message create", locals())


def list(name, resource_group=None, scope=None):
    '''
    List the non-compliance messages for a policy assignment.

    Required Parameters:
    - name -- Name of the policy assignment.

    Optional Parameters:
    - resource_group -- the resource group where the policy will be applied
    - scope -- Scope to which this policy assignment applies.
    '''
    return _call_az("az policy assignment non-compliance-message list", locals())


def delete(message, name, policy_definition_reference_id=None, resource_group=None, scope=None):
    '''
    Remove one or more non-compliance messages from a policy assignment.

    Required Parameters:
    - message -- Message that will be shown when a resource is denied by policy or evaluation details are inspected.
    - name -- Name of the policy assignment.

    Optional Parameters:
    - policy_definition_reference_id -- Policy definition reference ID within the assigned initiative (policy set) that the message applies to.
    - resource_group -- the resource group where the policy will be applied
    - scope -- Scope to which this policy assignment applies.
    '''
    return _call_az("az policy assignment non-compliance-message delete", locals())




from ... pyaz_utils import _call_az

def list(location):
    '''
    Show all commitment tiers for Azure Cognitive Services.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az cognitiveservices commitment-tier list", locals())




'''
List reservation summaries.
'''
from .... pyaz_utils import _call_az

def list(grain, reservation_order_id, end_date=None, reservation_id=None, start_date=None):
    '''
    List reservation summaries for daily or monthly by order Id or reservation id.

    Required Parameters:
    - grain -- Reservation summary grain. Possible values are daily or monthly.
    - reservation_order_id -- Reservation order id.

    Optional Parameters:
    - end_date -- End date (YYYY-MM-DD in UTC). Only needed for daily grain and if specified, also requires --start-date.
    - reservation_id -- Reservation id.
    - start_date -- Start date (YYYY-MM-DD in UTC). Only needed for daily grain and if specified, also requires --end-date.
    '''
    return _call_az("az consumption reservation summary list", locals())




'''
Create a connection between a webapp and a target resource
'''
from .... pyaz_utils import _call_az

def postgres(client_type=None, connection=None, database=None, name=None, new=None, no_wait=None, resource_group=None, secret=None, server=None, source_id=None, target_id=None, target_resource_group=None):
    '''
    Create a webapp connection to postgres.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - database -- Name of postgres database. Required if '--target-id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - new -- Indicates whether to create a new postgres when creating the webapp connection
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - server -- Name of postgres server. Required if '--target-id' is not specified.
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    - target_id -- The resource id of target service. Required if ['--target-resource-group', '--server', '--database'] are not specified.
    - target_resource_group -- The resource group which contains the postgres service. Required if '--target-id' is not specified.
    '''
    return _call_az("az webapp connection create postgres", locals())


def postgres_flexible(client_type=None, connection=None, database=None, name=None, no_wait=None, resource_group=None, secret=None, server=None, source_id=None, target_id=None, target_resource_group=None):
    '''
    Create a webapp connection to postgres-flexible.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - database -- Name of postgres flexible database. Required if '--target-id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - server -- Name of postgres flexible server. Required if '--target-id' is not specified.
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    - target_id -- The resource id of target service. Required if ['--target-resource-group', '--server', '--database'] are not specified.
    - target_resource_group -- The resource group which contains the flexible postgres service. Required if '--target-id' is not specified.
    '''
    return _call_az("az webapp connection create postgres-flexible", locals())


def mysql(client_type=None, connection=None, database=None, name=None, no_wait=None, resource_group=None, secret=None, server=None, source_id=None, target_id=None, target_resource_group=None):
    '''
    Create a webapp connection to mysql.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - database -- Name of the mysql database. Required if '--target-id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - server -- Name of the mysql server. Required if '--target-id' is not specified.
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    - target_id -- The resource id of target service. Required if ['--target-resource-group', '--server', '--database'] are not specified.
    - target_resource_group -- The resource group which contains the mysql server. Required if '--target-id' is not specified.
    '''
    return _call_az("az webapp connection create mysql", locals())


def mysql_flexible(client_type=None, connection=None, database=None, name=None, no_wait=None, resource_group=None, secret=None, server=None, source_id=None, target_id=None, target_resource_group=None):
    '''
    Create a webapp connection to mysql-flexible.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - database -- Name of the mysql flexible database. Required if '--target-id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - server -- Name of the mysql flexible server. Required if '--target-id' is not specified.
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    - target_id -- The resource id of target service. Required if ['--target-resource-group', '--server', '--database'] are not specified.
    - target_resource_group -- The resource group which contains the mysql flexible server. Required if '--target-id' is not specified.
    '''
    return _call_az("az webapp connection create mysql-flexible", locals())


def cosmos_cassandra(account=None, client_type=None, connection=None, key_space=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to cosmos-cassandra.

    Optional Parameters:
    - account -- Name of the cosmos database account. Required if '--target-id' is not specified.
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - key_space -- Name of the keyspace. Required if '--target-id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    - system_identity -- The system assigned identity auth info
    - target_id -- The resource id of target service. Required if ['--target-resource-group', '--account', '--key-space'] are not specified.
    - target_resource_group -- The resource group which contains the cosmos database account. Required if '--target-id' is not specified.
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection create cosmos-cassandra", locals())


def cosmos_gremlin(account=None, client_type=None, connection=None, database=None, graph=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to cosmos-gremlin.

    Optional Parameters:
    - account -- Name of the cosmos database account. Required if '--target-id' is not specified.
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - database -- Name of the database. Required if '--target-id' is not specified.
    - graph -- Name of the graph. Required if '--target-id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    - system_identity -- The system assigned identity auth info
    - target_id -- The resource id of target service. Required if ['--target-resource-group', '--account', '--database', '--graph'] are not specified.
    - target_resource_group -- The resource group which contains the cosmos database account. Required if '--target-id' is not specified.
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection create cosmos-gremlin", locals())


def cosmos_mongo(account=None, client_type=None, connection=None, database=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to cosmos-mongo.

    Optional Parameters:
    - account -- Name of the cosmos database account. Required if '--target-id' is not specified.
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - database -- Name of the database. Required if '--target-id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    - system_identity -- The system assigned identity auth info
    - target_id -- The resource id of target service. Required if ['--target-resource-group', '--account', '--database'] are not specified.
    - target_resource_group -- The resource group which contains the cosmos database account. Required if '--target-id' is not specified.
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection create cosmos-mongo", locals())


def cosmos_table(account=None, client_type=None, connection=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, source_id=None, system_identity=None, table=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to cosmos-table.

    Optional Parameters:
    - account -- Name of the cosmos database account. Required if '--target-id' is not specified.
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    - system_identity -- The system assigned identity auth info
    - table -- Name of the table. Required if '--target-id' is not specified.
    - target_id -- The resource id of target service. Required if ['--target-resource-group', '--account', '--table'] are not specified.
    - target_resource_group -- The resource group which contains the cosmos database account. Required if '--target-id' is not specified.
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection create cosmos-table", locals())


def cosmos_sql(account=None, client_type=None, connection=None, database=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to cosmos-sql.

    Optional Parameters:
    - account -- Name of the cosmos database account. Required if '--target-id' is not specified.
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - database -- Name of the database. Required if '--target-id' is not specified.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    - system_identity -- The system assigned identity auth info
    - target_id -- The resource id of target service. Required if ['--target-resource-group', '--account', '--database'] are not specified.
    - target_resource_group -- The resource group which contains the cosmos database account. Required if '--target-id' is not specified.
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection create cosmos-sql", locals())


def storage_blob(account=None, client_type=None, connection=None, name=None, new=None, no_wait=None, resource_group=None, secret=None, service_principal=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to storage-blob.

    Optional Parameters:
    - account -- Name of the storage account. Required if '--target-id' is not specified.
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - new -- Indicates whether to create a new storage-blob when creating the webapp connection
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    - system_identity -- The system assigned identity auth info
    - target_id -- The resource id of target service. Required if ['--target-resource-group', '--account'] are not specified.
    - target_resource_group -- The resource group which contains the storage account. Required if '--target-id' is not specified.
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection create storage-blob", locals())


def storage_queue(account=None, client_type=None, connection=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to storage-queue.

    Optional Parameters:
    - account -- Name of the storage account. Required if '--target-id' is not specified.
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    - system_identity -- The system assigned identity auth info
    - target_id -- The resource id of target service. Required if ['--target-resource-group', '--account'] are not specified.
    - target_resource_group -- The resource group which contains the storage account. Required if '--target-id' is not specified.
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection create storage-queue", locals())


def storage_file(account=None, client_type=None, connection=None, name=None, no_wait=None, resource_group=None, secret=None, source_id=None, target_id=None, target_resource_group=None):
    '''
    Create a webapp connection to storage-file.

    Optional Parameters:
    - account -- Name of the storage account. Required if '--target-id' is not specified.
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    - target_id -- The resource id of target service. Required if ['--target-resource-group', '--account'] are not specified.
    - target_resource_group -- The resource group which contains the storage account. Required if '--target-id' is not specified.
    '''
    return _call_az("az webapp connection create storage-file", locals())


def storage_table(account=None, client_type=None, connection=None, name=None, no_wait=None, resource_group=None, secret=None, source_id=None, target_id=None, target_resource_group=None):
    '''
    Create a webapp connection to storage-table.

    Optional Parameters:
    - account -- Name of the storage account. Required if '--target-id' is not specified.
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    - target_id -- The resource id of target service. Required if ['--target-resource-group', '--account'] are not specified.
    - target_resource_group -- The resource group which contains the storage account. Required if '--target-id' is not specified.
    '''
    return _call_az("az webapp connection create storage-table", locals())


def keyvault(client_type=None, connection=None, name=None, new=None, no_wait=None, resource_group=None, service_principal=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None, vault=None):
    '''
    Create a webapp connection to keyvault.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - new -- Indicates whether to create a new keyvault when creating the webapp connection
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - service_principal -- The service principal auth info
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    - system_identity -- The system assigned identity auth info
    - target_id -- The resource id of target service. Required if ['--target-resource-group', '--vault'] are not specified.
    - target_resource_group -- The resource group which contains the keyvault. Required if '--target-id' is not specified.
    - user_identity -- The user assigned identity auth info
    - vault -- Name of the keyvault. Required if '--target-id' is not specified.
    '''
    return _call_az("az webapp connection create keyvault", locals())


def signalr(client_type=None, connection=None, name=None, no_wait=None, resource_group=None, secret=None, service_principal=None, signalr=None, source_id=None, system_identity=None, target_id=None, target_resource_group=None, user_identity=None):
    '''
    Create a webapp connection to signalr.

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the webapp connection.
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - secret -- The secret auth info
    - service_principal -- The service principal auth info
    - signalr -- Name of the signalr service. Required if '--target-id' is not specified.
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    - system_identity -- The system assigned identity auth info
    - target_id -- The resource id of target service. Required if ['--target-resource-group', '--signalr'] are not specified.
    - target_resource_group -- The resource group which contains the signalr. Required if '--target-id' is not specified.
    - user_identity -- The user assigned identity auth info
    '''
    return _call_az("az webapp connection create signalr", locals())


def confluent_cloud(bootstrap_server, kafka_key, kafka_secret, schema_key, schema_registry, schema_secret, client_type=None, connection=None, name=None, no_wait=None, resource_group=None, source_id=None):
    '''
    Create a webapp connection to confluent-cloud.

    Required Parameters:
    - bootstrap_server -- Kafka bootstrap server url
    - kafka_key -- Kafka API-Key (key)
    - kafka_secret -- Kafka API-Key (secret)
    - schema_key -- Schema registry API-Key (key)
    - schema_registry -- Schema registry url
    - schema_secret -- Schema registry API-Key (secret)

    Optional Parameters:
    - client_type -- The client type used on the webapp
    - connection -- Name of the connection
    - name -- Name of the webapp. Required if '--source-id' is not specified.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- The resource group which contains the webapp. Required if '--source-id' is not specified.
    - source_id -- The resource id of a webapp. Required if ['--resource-group', '--name'] are not specified.
    '''
    return _call_az("az webapp connection create confluent-cloud", locals())




'''
Manage Azure Service Bus Migration of Standard to Premium
'''
from ... pyaz_utils import _call_az

def start(name, post_migration_name, resource_group, target_namespace):
    '''
    Create and Start Service Bus Migration of Standard to Premium namespace.

    Required Parameters:
    - name -- Name of Standard Namespace used as source of the migration
    - post_migration_name -- Post migration name is the name that can be used to connect to standard namespace after migration is complete.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - target_namespace -- Name (if within the same resource group) or ARM Id of empty Premium Service Bus namespace name that will be target of the migration
    '''
    return _call_az("az servicebus migration start", locals())


def show(name, resource_group):
    '''
    shows properties of properties of Service Bus Migration

    Required Parameters:
    - name -- Name of Standard Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus migration show", locals())


def complete(name, resource_group):
    '''
    Completes the Service Bus Migration of Standard to Premium namespace

    Required Parameters:
    - name -- Name of Standard Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus migration complete", locals())


def abort(name, resource_group):
    '''
    Disable the Service Bus Migration of Standard to Premium namespace

    Required Parameters:
    - name -- Name of Standard Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus migration abort", locals())




'''
Manage keys.
'''
from ... pyaz_utils import _call_az
from . import rotation_policy


def list(hsm_name=None, id=None, include_managed=None, maxresults=None, vault_name=None):
    '''
    List keys in the specified Vault or HSM.

    Optional Parameters:
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Full URI of the Vault or HSM. If specified all other 'Id' arguments should be omitted.
    - include_managed -- Include managed keys. Default: false
    - maxresults -- Maximum number of results to return in a page. If not specified the service will return up to 25 results.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault key list", locals())


def list_versions(hsm_name=None, id=None, maxresults=None, name=None, vault_name=None):
    '''
    

    Optional Parameters:
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Id of the key. If specified all other 'Id' arguments should be omitted.
    - maxresults -- Maximum number of results to return in a page. If not specified the service will return up to 25 results.
    - name -- Name of the key. Required if --id is not specified.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault key list-versions", locals())


def list_deleted(hsm_name=None, id=None, maxresults=None, vault_name=None):
    '''
    List the deleted keys in the specified Vault or HSM.

    Optional Parameters:
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Full URI of the Vault or HSM. If specified all other 'Id' arguments should be omitted.
    - maxresults -- Maximum number of results to return in a page. If not specified the service will return up to 25 results.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault key list-deleted", locals())


def show_deleted(hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Get the public part of a deleted key.

    Optional Parameters:
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- The recovery id of the key. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the key. Required if --id is not specified.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault key show-deleted", locals())


def delete(hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Delete a key of any type from storage in Vault or HSM.

    Optional Parameters:
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Id of the key. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the key. Required if --id is not specified.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault key delete", locals())


def purge(hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Permanently delete the specified key.

    Optional Parameters:
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- The recovery id of the key. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the key. Required if --id is not specified.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault key purge", locals())


def recover(hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Recover the deleted key to its latest version.

    Optional Parameters:
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- The recovery id of the key. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the key. Required if --id is not specified.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault key recover", locals())


def backup(file, hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Request that a backup of the specified key be downloaded to the client.

    Required Parameters:
    - file -- Local file path in which to store key backup.

    Optional Parameters:
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Id of the key. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the key. Required if --id is not specified.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault key backup", locals())


def restore(backup_folder=None, blob_container_name=None, file=None, hsm_name=None, id=None, name=None, no_wait=None, storage_account_name=None, storage_container_SAS_token=None, storage_resource_uri=None, vault_name=None):
    '''
    Restore a backed up key to a Vault or HSM.

    Optional Parameters:
    - backup_folder -- Name of the blob container which contains the backup
    - blob_container_name -- Name of Blob Container.
    - file -- Local key backup from which to restore key.
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Full URI of the Vault or HSM. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the key. (Only for restoring from storage account)
    - no_wait -- Do not wait for the long-running operation to finish.
    - storage_account_name -- Name of Azure Storage Account.
    - storage_container_SAS_token -- The SAS token pointing to an Azure Blob storage container
    - storage_resource_uri -- Azure Blob storage container Uri. If specified, all other 'Storage Id' arguments should be omitted
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault key restore", locals())


def download(file, encoding=None, hsm_name=None, id=None, name=None, vault_name=None, version=None):
    '''
    Download the public part of a stored key.

    Required Parameters:
    - file -- File to receive the key contents.

    Optional Parameters:
    - encoding -- Encoding of the key, default: PEM
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Id of the key. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the key. Required if --id is not specified.
    - vault_name -- Name of the Vault.
    - version -- The key version. If omitted, uses the latest version.
    '''
    return _call_az("az keyvault key download", locals())


def create(curve=None, disabled=None, expires=None, exportable=None, hsm_name=None, id=None, kty=None, name=None, not_before=None, ops=None, policy=None, protection=None, size=None, tags=None, vault_name=None):
    '''
    Create a new key, stores it, then returns key parameters and attributes to the client.

    Optional Parameters:
    - curve -- Elliptic curve name. For valid values, see: https://docs.microsoft.com/rest/api/keyvault/createkey/createkey#jsonwebkeycurvename
    - disabled -- Create key in disabled state.
    - expires -- Expiration UTC datetime  (Y-m-d'T'H:M:S'Z').
    - exportable -- Whether the private key can be exported. To create key with release policy, "exportable" must be true and caller must have "export" permission.
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Id of the key. If specified all other 'Id' arguments should be omitted.
    - kty -- The type of key to create. For valid values, see: https://docs.microsoft.com/rest/api/keyvault/createkey/createkey#jsonwebkeytype
    - name -- Name of the key. Required if --id is not specified.
    - not_before -- Key not usable before the provided UTC datetime  (Y-m-d'T'H:M:S'Z').
    - ops -- Space-separated list of permitted JSON web key operations.
    - policy -- The policy rules under which the key can be exported. Policy definition as JSON, or a path to a file containing JSON policy definition.
    - protection -- Specifies the type of key protection.
    - size -- The key size in bits. For example: 2048, 3072, or 4096 for RSA. 128, 192, or 256 for oct.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault key create", locals())


def set_attributes(enabled=None, expires=None, hsm_name=None, id=None, name=None, not_before=None, ops=None, policy=None, tags=None, vault_name=None, version=None):
    '''
    The update key operation changes specified attributes of a stored key and can be applied to any key type and key version stored in Vault or HSM.

    Optional Parameters:
    - enabled -- Enable the key.
    - expires -- Expiration UTC datetime  (Y-m-d'T'H:M:S'Z').
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Id of the key. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the key. Required if --id is not specified.
    - not_before -- Key not usable before the provided UTC datetime  (Y-m-d'T'H:M:S'Z').
    - ops -- Space-separated list of permitted JSON web key operations.
    - policy -- The policy rules under which the key can be exported. Policy definition as JSON, or a path to a file containing JSON policy definition.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vault_name -- Name of the Vault.
    - version -- The key version. If omitted, uses the latest version.
    '''
    return _call_az("az keyvault key set-attributes", locals())


def show(hsm_name=None, id=None, name=None, vault_name=None, version=None):
    '''
    

    Optional Parameters:
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Id of the key. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the key. Required if --id is not specified.
    - vault_name -- Name of the Vault.
    - version -- The key version. If omitted, uses the latest version.
    '''
    return _call_az("az keyvault key show", locals())


def import_(byok_file=None, byok_string=None, curve=None, disabled=None, expires=None, exportable=None, hsm_name=None, id=None, kty=None, name=None, not_before=None, ops=None, pem_file=None, pem_password=None, pem_string=None, policy=None, protection=None, tags=None, vault_name=None):
    '''
    

    Optional Parameters:
    - byok_file -- BYOK file containing the key to be imported. Must not be password protected.
    - byok_string -- BYOK string containing the key to be imported. Must not be password protected.
    - curve -- The curve name of the key to import (only for BYOK).
    - disabled -- Create key in disabled state.
    - expires -- Expiration UTC datetime  (Y-m-d'T'H:M:S'Z').
    - exportable -- Whether the private key can be exported. To create key with release policy, "exportable" must be true and caller must have "export" permission.
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Id of the key. If specified all other 'Id' arguments should be omitted.
    - kty -- The type of key to import (only for BYOK).
    - name -- Name of the key. Required if --id is not specified.
    - not_before -- Key not usable before the provided UTC datetime  (Y-m-d'T'H:M:S'Z').
    - ops -- Space-separated list of permitted JSON web key operations.
    - pem_file -- PEM file containing the key to be imported.
    - pem_password -- Password of PEM file.
    - pem_string -- PEM string containing the key to be imported.
    - policy -- The policy rules under which the key can be exported. Policy definition as JSON, or a path to a file containing JSON policy definition.
    - protection -- Specifies the type of key protection.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault key import", locals())


def get_policy_template():
    '''
    Return policy template as JSON encoded policy definition.
    '''
    return _call_az("az keyvault key get-policy-template", locals())


def encrypt(algorithm, value, aad=None, data_type=None, hsm_name=None, id=None, iv=None, name=None, vault_name=None, version=None):
    '''
    Encrypt an arbitrary sequence of bytes using an encryption key that is stored in a Vault or HSM.

    Required Parameters:
    - algorithm -- Algorithm identifier
    - value -- The value to be encrypted. Default data type is Base64 encoded string.

    Optional Parameters:
    - aad -- Optional data that is authenticated but not encrypted. For use with AES-GCM encryption.
    - data_type -- The type of the original data.
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Id of the key. If specified all other 'Id' arguments should be omitted.
    - iv -- Initialization vector. Required for only AES-CBC(PAD) encryption.
    - name -- Name of the key. Required if --id is not specified.
    - vault_name -- Name of the Vault.
    - version -- The key version. If omitted, uses the latest version.
    '''
    return _call_az("az keyvault key encrypt", locals())


def decrypt(algorithm, value, aad=None, data_type=None, hsm_name=None, id=None, iv=None, name=None, tag=None, vault_name=None, version=None):
    '''
    Decrypt a single block of encrypted data.

    Required Parameters:
    - algorithm -- Algorithm identifier
    - value -- The value to be decrypted, which should be the result of "az keyvault encrypt"

    Optional Parameters:
    - aad -- Optional data that is authenticated but not encrypted. For use with AES-GCM decryption.
    - data_type -- The type of the original data.
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Id of the key. If specified all other 'Id' arguments should be omitted.
    - iv -- The initialization vector used during encryption. Required for AES decryption.
    - name -- Name of the key. Required if --id is not specified.
    - tag -- The authentication tag generated during encryption. Required for only AES-GCM decryption.
    - vault_name -- Name of the Vault.
    - version -- The key version. If omitted, uses the latest version.
    '''
    return _call_az("az keyvault key decrypt", locals())


def random(count, hsm_name=None, id=None):
    '''
    

    Required Parameters:
    - count -- The requested number of random bytes.

    Optional Parameters:
    - hsm_name -- Name of the HSM.
    - id -- Full URI of the HSM.
    '''
    return _call_az("az keyvault key random", locals())


def rotate(hsm_name=None, id=None, name=None, vault_name=None):
    '''
    Rotate the key based on the key policy by generating a new version of the key.

    Optional Parameters:
    - hsm_name -- Name of the HSM. (--hsm-name and --vault-name are mutually exclusive, please specify just one of them)
    - id -- Id of the key. If specified all other 'Id' arguments should be omitted.
    - name -- Name of the key. Required if --id is not specified.
    - vault_name -- Name of the Vault.
    '''
    return _call_az("az keyvault key rotate", locals())




from .... pyaz_utils import _call_az

def configure(nsg, enabled=None, format=None, interval=None, log_version=None, resource_group=None, retention=None, storage_account=None, traffic_analytics=None, workspace=None):
    '''
    Configure flow logging on a network security group.

    Required Parameters:
    - nsg -- Name or ID of the network security group.

    Optional Parameters:
    - enabled -- Enable logging
    - format -- File type of the flow log.
    - interval -- Interval in minutes at which to conduct flow analytics. Temporarily allowed values are 10 and 60.
    - log_version -- Version (revision) of the flow log.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - retention -- Number of days to retain logs
    - storage_account -- Name or ID of the storage account in which to save the flow logs. Must be in the same region of flow log.
    - traffic_analytics -- Enable traffic analytics. Defaults to true if `--workspace` is provided.
    - workspace -- Name or ID of a Log Analytics workspace. Must be in the same region of flow log
    '''
    return _call_az("az network watcher flow-log configure", locals())


def show(location=None, name=None, nsg=None, resource_group=None):
    '''
    Get the flow log configuration of a network security group.

    Optional Parameters:
    - location -- Location to identify the exclusive Network Watcher under a region. Only one Network Watcher can be existed per subscription and region.
    - name -- The name of the flow logger
    - nsg -- Name or ID of the network security group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network watcher flow-log show", locals())


def list(location):
    '''
    List all flow log resources for the specified Network Watcher

    Required Parameters:
    - location -- Location to identify the exclusive Network Watcher under a region. Only one Network Watcher can be existed per subscription and region.
    '''
    return _call_az("az network watcher flow-log list", locals())


def delete(location, name):
    '''
    Delete the specified flow log resource.

    Required Parameters:
    - location -- Location to identify the exclusive Network Watcher under a region. Only one Network Watcher can be existed per subscription and region.
    - name -- The name of the flow logger
    '''
    return _call_az("az network watcher flow-log delete", locals())


def create(location, name, nsg, enabled=None, format=None, interval=None, log_version=None, resource_group=None, retention=None, storage_account=None, tags=None, traffic_analytics=None, workspace=None):
    '''
    Create a flow log on a network security group.

    Required Parameters:
    - location -- Location to identify the exclusive Network Watcher under a region. Only one Network Watcher can be existed per subscription and region.
    - name -- The name of the flow logger
    - nsg -- Name or ID of the network security group.

    Optional Parameters:
    - enabled -- Enable logging
    - format -- File type of the flow log.
    - interval -- Interval in minutes at which to conduct flow analytics. Temporarily allowed values are 10 and 60.
    - log_version -- Version (revision) of the flow log.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - retention -- Number of days to retain logs
    - storage_account -- Name or ID of the storage account in which to save the flow logs. Must be in the same region of flow log.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - traffic_analytics -- Enable traffic analytics. Defaults to true if `--workspace` is provided.
    - workspace -- Name or ID of a Log Analytics workspace. Must be in the same region of flow log
    '''
    return _call_az("az network watcher flow-log create", locals())


def update(location, name, add=None, enabled=None, force_string=None, format=None, interval=None, log_version=None, nsg=None, remove=None, resource_group=None, retention=None, set=None, storage_account=None, tags=None, traffic_analytics=None, workspace=None):
    '''
    Update the flow log configuration of a network security group

    Required Parameters:
    - location -- Location to identify the exclusive Network Watcher under a region. Only one Network Watcher can be existed per subscription and region.
    - name -- The name of the flow logger

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - enabled -- Enable logging
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - format -- File type of the flow log.
    - interval -- Interval in minutes at which to conduct flow analytics. Temporarily allowed values are 10 and 60.
    - log_version -- Version (revision) of the flow log.
    - nsg -- Name or ID of the network security group.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - retention -- Number of days to retain logs
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - storage_account -- Name or ID of the storage account in which to save the flow logs. Must be in the same region of flow log.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - traffic_analytics -- Enable traffic analytics. Defaults to true if `--workspace` is provided.
    - workspace -- Name or ID of a Log Analytics workspace. Must be in the same region of flow log
    '''
    return _call_az("az network watcher flow-log update", locals())




'''
Manage Azure NetApp Files (ANF) Volume Resources.
'''
from ... pyaz_utils import _call_az
from . import backup, export_policy, replication


def show(account_name, pool_name, resource_group, volume_name):
    '''
    Get the specified ANF volume.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles volume show", locals())


def list(account_name, pool_name, resource_group):
    '''
    List the ANF Pools for the specified account.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles volume list", locals())


def delete(account_name, pool_name, resource_group, volume_name):
    '''
    Delete the specified ANF volume.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles volume delete", locals())


def create(account_name, file_path, location, pool_name, resource_group, usage_threshold, vnet, volume_name, allowed_clients=None, avs_data_store=None, backup_enabled=None, backup_id=None, backup_policy_id=None, chown_mode=None, cifs=None, cool_access=None, coolness_period=None, default_group_quota=None, default_user_quota=None, encryption_key_source=None, endpoint_type=None, has_root_access=None, is_def_quota_enabled=None, kerberos5_r=None, kerberos5_rw=None, kerberos5i_r=None, kerberos5i_rw=None, kerberos5p_r=None, kerberos5p_rw=None, kerberos_enabled=None, ldap_enabled=None, network_features=None, policy_enforced=None, protocol_types=None, remote_volume_resource_id=None, replication_schedule=None, rule_index=None, security_style=None, service_level=None, smb_continuously_avl=None, smb_encryption=None, snapshot_dir_visible=None, snapshot_id=None, snapshot_policy_id=None, subnet=None, tags=None, throughput_mibps=None, unix_permissions=None, unix_read_only=None, unix_read_write=None, vault_id=None, volume_type=None):
    '''
    Create a new Azure NetApp Files (ANF) volume. Export policies are applied with the subgroup commands but note that volumes are always created with a default export policy

    Required Parameters:
    - account_name -- Name of the ANF account.
    - file_path -- None
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - usage_threshold -- Required. Maximum storage quota allowed for a file system in bytes. This is a soft quota used for alerting only. Minimum size is 100 GiB. Upper limit is 100TiB. Specified in bytes.
    - vnet -- None
    - volume_name -- Name of the ANF volume.

    Optional Parameters:
    - allowed_clients -- None
    - avs_data_store -- Specifies whether the volume is enabled for Azure VMware Solution (AVS) datastore purpose. Possible values include: "Enabled", "Disabled". Default value: "Disabled".
    - backup_enabled -- None
    - backup_id -- UUID v4 or resource identifier used to identify the Backup.
    - backup_policy_id -- None
    - chown_mode -- None
    - cifs -- None
    - cool_access -- Specifies whether Cool Access(tiering) is enabled for the volume.
    - coolness_period -- Specifies the number of days after which data that is not accessed by clients will be tiered.
    - default_group_quota -- None
    - default_user_quota -- None
    - encryption_key_source -- Encryption Key Source. Possible values are: 'Microsoft.NetApp'.
    - endpoint_type -- None
    - has_root_access -- None
    - is_def_quota_enabled -- None
    - kerberos5_r -- None
    - kerberos5_rw -- None
    - kerberos5i_r -- None
    - kerberos5i_rw -- None
    - kerberos5p_r -- None
    - kerberos5p_rw -- None
    - kerberos_enabled -- Describe if a volume is KerberosEnabled. To be use with swagger version 2020-05-01 or later.
    - ldap_enabled -- Specifies whether LDAP is enabled or not for a given NFS volume.
    - network_features -- Basic network, or Standard features available to the volume. Possible values include: "Basic", "Standard". Default value: "Basic".
    - policy_enforced -- None
    - protocol_types -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - remote_volume_resource_id -- None
    - replication_schedule -- None
    - rule_index -- None
    - security_style -- The security style of volume, default unix, defaults to ntfs for dual protocol or CIFS protocol. Possible values include: "ntfs", "unix". Default value: "unix".
    - service_level -- Service level
    - smb_continuously_avl -- None
    - smb_encryption -- Enables encryption for in-flight smb3 data. Only applicable for SMB/DualProtocol volume. To be used with swagger version 2020-08-01 or later.
    - snapshot_dir_visible -- None
    - snapshot_id -- UUID v4 or resource identifier used to identify the Snapshot.
    - snapshot_policy_id -- None
    - subnet -- None
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - throughput_mibps -- Maximum throughput in Mibps that can be achieved by this volume.
    - unix_permissions -- UNIX permissions for NFS volume accepted in octal 4 digit format. First digit selects the set user ID(4), set group ID (2) and sticky (1) attributes. Second digit selects permission for the owner of the file: read (4), write (2) and execute (1). Third selects permissions for other users in the same group. the fourth for other users not in the group. 0755 - gives read/write/execute permissions to owner and read/execute to group and other users.
    - unix_read_only -- None
    - unix_read_write -- None
    - vault_id -- None
    - volume_type -- What type of volume is this. For destination volumes in Cross Region Replication, set type to DataProtection.
    '''
    return _call_az("az netappfiles volume create", locals())


def update(account_name, pool_name, resource_group, volume_name, add=None, backup_enabled=None, backup_policy_id=None, default_group_quota=None, default_user_quota=None, force_string=None, is_def_quota_enabled=None, policy_enforced=None, remove=None, service_level=None, set=None, snapshot_policy_id=None, tags=None, throughput_mibps=None, usage_threshold=None, vault_id=None):
    '''
    Update the specified ANF volume with the values provided. Unspecified values will remain unchanged. Export policies are amended/created with the subgroup commands

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - backup_enabled -- None
    - backup_policy_id -- None
    - default_group_quota -- None
    - default_user_quota -- None
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - is_def_quota_enabled -- None
    - policy_enforced -- None
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - service_level -- Service level
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - snapshot_policy_id -- None
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - throughput_mibps -- Maximum throughput in Mibps that can be achieved by this volume.
    - usage_threshold -- Maximum storage quota allowed for a file system in bytes. This is a soft quota used for alerting only. Minimum size is 100 GiB. Upper limit is 100TiB. Specified in bytes.
    - vault_id -- None
    '''
    return _call_az("az netappfiles volume update", locals())


def revert(account_name, pool_name, resource_group, snapshot_id, volume_name):
    '''
    Revert a volume to one of its snapshots.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - snapshot_id -- Resource id of the snapshot
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles volume revert", locals())


def pool_change(account_name, new_pool_resource_id, pool_name, resource_group, volume_name):
    '''
    Change pool for an Azure NetApp Files (ANF) volume.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - new_pool_resource_id -- Resource id of the new pool
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles volume pool-change", locals())




from ... pyaz_utils import _call_az

def create(account_name, asset_name, name, resource_group, streaming_policy_name, alternative_media_id=None, content_key_policy_name=None, content_keys=None, end_time=None, filters=None, start_time=None, streaming_locator_id=None):
    '''
    Create a streaming locator.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - asset_name -- The name of the asset used by the streaming locator.
    - name -- The name of the streaming locator.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - streaming_policy_name -- The name of the streaming policy used by the streaming locator. You can either create one with `az ams streaming policy create` or use any of the predefined policies: Predefined_DownloadOnly, Predefined_ClearStreamingOnly, Predefined_DownloadAndClearStreaming, Predefined_ClearKey, Predefined_MultiDrmCencStreaming, Predefined_MultiDrmStreaming

    Optional Parameters:
    - alternative_media_id -- An alternative media identifier associated with the streaming locator.
    - content_key_policy_name -- The default content key policy name used by the streaming locator.
    - content_keys -- JSON string with the content keys to be used by the streaming locator. Use @{file} to load from a file. For further information about the JSON structure please refer to swagger documentation on https://docs.microsoft.com/rest/api/media/streaminglocators/create#streaminglocatorcontentkey
    - end_time -- The ISO 8601 DateTime end time (Y-m-d'T'H:M:S'Z') of the streaming locator.
    - filters -- A space-separated list of asset filter names and/or account filter names.
    - start_time -- The ISO 8601 DateTime start time (Y-m-d'T'H:M:S'Z') of the streaming locator.
    - streaming_locator_id -- The identifier of the streaming locator.
    '''
    return _call_az("az ams streaming-locator create", locals())


def list(account_name, resource_group, filter=None, orderby=None, top=None):
    '''
    List all the streaming locators within an Azure Media Services account.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - filter -- Restricts the set of items returned.
    - orderby -- Specifies the key by which the result collection should be ordered.
    - top -- Specifies a non-negative integer n that limits the number of items returned from a collection. The service returns the number of available items up to but not greater than the specified value n.
    '''
    return _call_az("az ams streaming-locator list", locals())


def show(account_name, name, resource_group):
    '''
    Show the details of a streaming locator.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming locator.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams streaming-locator show", locals())


def delete(account_name, name, resource_group):
    '''
    

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming locator.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams streaming-locator delete", locals())


def get_paths(account_name, name, resource_group):
    '''
    List paths supported by a streaming locator.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming locator.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams streaming-locator get-paths", locals())


def list_content_keys(account_name, name, resource_group):
    '''
    List content keys used by a streaming locator.

    Required Parameters:
    - account_name -- The name of the Azure Media Services account.
    - name -- The name of the streaming locator.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az ams streaming-locator list-content-keys", locals())




from ... pyaz_utils import _call_az

def cancel(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vmss rolling-upgrade cancel", locals())


def get_latest(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vmss rolling-upgrade get-latest", locals())


def start(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vmss rolling-upgrade start", locals())




from ..... pyaz_utils import _call_az

def show(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql server ms-support audit-policy show", locals())


def update(name, resource_group, add=None, blob_storage_target_state=None, event_hub=None, event_hub_authorization_rule_id=None, event_hub_target_state=None, force_string=None, log_analytics_target_state=None, log_analytics_workspace_resource_id=None, no_wait=None, remove=None, set=None, state=None, storage_account=None, storage_endpoint=None, storage_key=None):
    '''
    Update a server's Microsoft support operations auditing policy.

    Required Parameters:
    - name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - blob_storage_target_state -- Indicate whether blob storage is a destination for audit records.
    - event_hub -- The name of the event hub. If none is specified when providing event_hub_authorization_rule_id, the default event hub will be selected.
    - event_hub_authorization_rule_id -- The resource Id for the event hub authorization rule.
    - event_hub_target_state -- Indicate whether event hub is a destination for audit records.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - log_analytics_target_state -- Indicate whether log analytics is a destination for audit records.
    - log_analytics_workspace_resource_id -- The workspace ID (resource ID of a Log Analytics workspace) for a Log Analytics workspace to which you would like to send Audit Logs.
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - state -- Auditing policy state
    - storage_account -- Name of the storage account.
    - storage_endpoint -- The storage account endpoint.
    - storage_key -- Access key for the storage account.
    '''
    return _call_az("az sql server ms-support audit-policy update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the server's Microsoft support operations audit policy is met.

    Required Parameters:
    - name -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az sql server ms-support audit-policy wait", locals())




from ... pyaz_utils import _call_az

def create(deployment_mode, parameters_path, resource_group, service_name, service_topology_name, service_unit_name, target_resource_group, template_path, location=None, tags=None):
    '''
    Creates a service unit under the specified service and service topology.

    Required Parameters:
    - deployment_mode -- The type of depoyment mode to be used when deploying the service unit. Possible values: Incremental, Complete
    - parameters_path -- The path to the ARM parameters file. Either the full SAS Uri or the relative path in the artifact source for this topology.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the service
    - service_topology_name -- The name of the service topology
    - service_unit_name -- The name of the service unit
    - target_resource_group -- The resource group where the resources in the service unit should be deployed to
    - template_path -- The path to the ARM template file. Either the full SAS Uri or the relative path in the artifact source for this topology.

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az deploymentmanager service-unit create", locals())


def delete(resource_group, service_name, service_topology_name, service_unit_name):
    '''
    Deletes the service unit.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the service
    - service_topology_name -- The name of the service topology
    - service_unit_name -- The name of the service unit
    '''
    return _call_az("az deploymentmanager service-unit delete", locals())


def show(resource_group, service_name, service_topology_name, service_unit_name):
    '''
    Get the details of a service unit.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the service
    - service_topology_name -- The name of the service topology
    - service_unit_name -- The name of the service unit
    '''
    return _call_az("az deploymentmanager service-unit show", locals())


def list(resource_group, service_name, service_topology_name):
    '''
    List all service units in a service.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the service
    - service_topology_name -- The name of the service topology
    '''
    return _call_az("az deploymentmanager service-unit list", locals())


def update(resource_group, service_name, service_topology_name, service_unit_name, add=None, deployment_mode=None, force_string=None, parameters_path=None, remove=None, set=None, tags=None, target_resource_group=None, template_path=None):
    '''
    Updates the service unit.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the service
    - service_topology_name -- The name of the service topology
    - service_unit_name -- The name of the service unit

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - deployment_mode -- The type of depoyment mode to be used when deploying the service unit. Possible values: Incremental, Complete
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - parameters_path -- The path to the ARM parameters file. Either the full SAS Uri or the relative path in the artifact source for this topology.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - target_resource_group -- The resource group where the resources in the service unit should be deployed to
    - template_path -- The path to the ARM template file. Either the full SAS Uri or the relative path in the artifact source for this topology.
    '''
    return _call_az("az deploymentmanager service-unit update", locals())




from ... pyaz_utils import _call_az

def show(custom_domain_name, profile_name, resource_group):
    '''
    Show the custom domain details.

    Required Parameters:
    - custom_domain_name -- Name of the custom domain.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd custom-domain show", locals())


def wait(custom_domain_name, profile_name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the custom domain is met.

    Required Parameters:
    - custom_domain_name -- Name of the custom domain.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az afd custom-domain wait", locals())


def delete(custom_domain_name, profile_name, resource_group, yes=None):
    '''
    Delete a custom domain.

    Required Parameters:
    - custom_domain_name -- Name of the custom domain.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az afd custom-domain delete", locals())


def list(profile_name, resource_group):
    '''
    List all the custom domains within the specified profile.

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd custom-domain list", locals())


def create(certificate_type, custom_domain_name, host_name, minimum_tls_version, profile_name, resource_group, azure_dns_zone=None, no_wait=None, secret=None):
    '''
    Create a custom domain within the specified profile.

    Required Parameters:
    - certificate_type -- Defines the source of the SSL certificate.
    - custom_domain_name -- Name of the custom domain.
    - host_name -- The host name of the domain. Must be a domain name.
    - minimum_tls_version -- TLS protocol version that will be used for Https.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - azure_dns_zone -- ID of the Azure DNS zone.
    - no_wait -- Do not wait for the long-running operation to finish.
    - secret -- Name of the azure front door secret.
    '''
    return _call_az("az afd custom-domain create", locals())


def update(custom_domain_name, profile_name, resource_group, azure_dns_zone=None, certificate_type=None, minimum_tls_version=None, secret=None):
    '''
    Update a custom domain within the specified profile.

    Required Parameters:
    - custom_domain_name -- Name of the custom domain.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - azure_dns_zone -- ID of the Azure DNS zone.
    - certificate_type -- Defines the source of the SSL certificate.
    - minimum_tls_version -- TLS protocol version that will be used for Https.
    - secret -- Name of the azure front door secret.
    '''
    return _call_az("az afd custom-domain update", locals())




'''
Manage custom hostnames of Functions of the static app.
'''
from ... pyaz_utils import _call_az

def list(name, resource_group=None):
    '''
    List custom hostnames of the static app.

    Required Parameters:
    - name -- Name of the static site

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp hostname list", locals())


def set(hostname, name, no_wait=None, resource_group=None, validation_method=None):
    '''
    Set given sub-domain hostname to the static app. Please configure CNAME/TXT/ALIAS record with your DNS provider. Use --no-wait to not wait for validation.

    Required Parameters:
    - hostname -- custom hostname such as www.example.com. Only support sub domain in preview.
    - name -- Name of the static site

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - validation_method -- Validation method for the custom domain.
    '''
    return _call_az("az staticwebapp hostname set", locals())


def delete(hostname, name, no_wait=None, resource_group=None, yes=None):
    '''
    Delete given hostname of the static app.

    Required Parameters:
    - hostname -- custom hostname such as www.example.com. Only support sub domain in preview.
    - name -- Name of the static site

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az staticwebapp hostname delete", locals())


def show(hostname, name, resource_group):
    '''
    Get details for a staticwebapp custom domain. Can be used to fetch validation token for TXT domain validation (see example).

    Required Parameters:
    - hostname -- custom hostname such as www.example.com. Only support sub domain in preview.
    - name -- Name of the static site
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az staticwebapp hostname show", locals())




'''
Manage Azure Service Bus Queue and Authorization Rule
'''
from ... pyaz_utils import _call_az
from . import authorization_rule


def create(name, namespace_name, resource_group, auto_delete_on_idle=None, default_message_time_to_live=None, duplicate_detection_history_time_window=None, enable_batched_operations=None, enable_dead_lettering_on_message_expiration=None, enable_duplicate_detection=None, enable_express=None, enable_partitioning=None, enable_session=None, forward_dead_lettered_messages_to=None, forward_to=None, lock_duration=None, max_delivery_count=None, max_size=None, status=None):
    '''
    Create the Service Bus Queue

    Required Parameters:
    - name -- Name of Queue
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - auto_delete_on_idle -- ISO 8601 timeSpan or duration time format for idle interval after which the queue is automatically deleted. The minimum duration is 5 minutes.
    - default_message_time_to_live -- ISO 8601 timespan or duration time format for default message to live value. This is the duration after which the message expires, starting from when the message is sent to Service Bus. This is the default value used when TimeToLive is not set on a message itself.
    - duplicate_detection_history_time_window -- ISO 8601 timeSpan structure that defines the duration of the duplicate detection history. The default value is 10 minutes.
    - enable_batched_operations -- Allow server-side batched operations.
    - enable_dead_lettering_on_message_expiration -- A boolean value that indicates whether this queue has dead letter support when a message expires.
    - enable_duplicate_detection -- A boolean value indicating if this queue requires duplicate detection.
    - enable_express -- A boolean value that indicates whether Express Entities are enabled. An express queue holds a message in memory temporarily before writing it to persistent storage.
    - enable_partitioning -- A boolean value that indicates whether the queue is to be partitioned across multiple message brokers.
    - enable_session -- A boolean value indicating whether the queue supports the concept of sessions.
    - forward_dead_lettered_messages_to -- Queue/Topic name to forward the Dead Letter message
    - forward_to -- Queue/Topic name to forward the messages
    - lock_duration -- String ISO 8601 timespan or duration format for duration of a peek-lock; that is, the amount of time that the message is locked for other receivers. The maximum value for LockDuration is 5 minutes; the default value is 1 minute.
    - max_delivery_count -- The maximum delivery count. A message is automatically deadlettered after this number of deliveries. default value is 10.
    - max_size -- Maximum size of queue in megabytes, which is the size of the memory allocated for the queue. Default is 1024. Max for Standard SKU is 5120 and for Premium SKU is 81920
    - status -- Enumerates the possible values for the status of a messaging entity.
    '''
    return _call_az("az servicebus queue create", locals())


def show(name, namespace_name, resource_group):
    '''
    shows the Service Bus Queue Details

    Required Parameters:
    - name -- Name of Queue
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus queue show", locals())


def list(namespace_name, resource_group, skip=None, top=None):
    '''
    List the Queue by Service Bus Namespace

    Required Parameters:
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - skip -- Skip is only used if a previous operation returned a partial result. If a previous response contains a nextLink element, the value of the nextLink element will include a skip parameter that specifies a starting point to use for subsequent calls.
    - top -- May be used to limit the number of results to the most recent N usageDetails.
    '''
    return _call_az("az servicebus queue list", locals())


def delete(name, namespace_name, resource_group):
    '''
    Deletes the Service Bus Queue

    Required Parameters:
    - name -- Name of Queue
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus queue delete", locals())


def update(name, namespace_name, resource_group, add=None, auto_delete_on_idle=None, default_message_time_to_live=None, duplicate_detection_history_time_window=None, enable_batched_operations=None, enable_dead_lettering_on_message_expiration=None, enable_duplicate_detection=None, enable_express=None, enable_partitioning=None, enable_session=None, force_string=None, forward_dead_lettered_messages_to=None, forward_to=None, lock_duration=None, max_delivery_count=None, max_size=None, remove=None, set=None, status=None):
    '''
    Updates existing Service Bus Queue

    Required Parameters:
    - name -- Name of Queue
    - namespace_name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - auto_delete_on_idle -- ISO 8601 timeSpan or duration time format for idle interval after which the queue is automatically deleted. The minimum duration is 5 minutes.
    - default_message_time_to_live -- ISO 8601 timespan or duration time format for default message to live value. This is the duration after which the message expires, starting from when the message is sent to Service Bus. This is the default value used when TimeToLive is not set on a message itself.
    - duplicate_detection_history_time_window -- ISO 8601 timeSpan structure that defines the duration of the duplicate detection history. The default value is 10 minutes.
    - enable_batched_operations -- Allow server-side batched operations.
    - enable_dead_lettering_on_message_expiration -- A boolean value that indicates whether this queue has dead letter support when a message expires.
    - enable_duplicate_detection -- A boolean value indicating if this queue requires duplicate detection.
    - enable_express -- A boolean value that indicates whether Express Entities are enabled. An express queue holds a message in memory temporarily before writing it to persistent storage.
    - enable_partitioning -- A boolean value that indicates whether the queue is to be partitioned across multiple message brokers.
    - enable_session -- A boolean value indicating whether the queue supports the concept of sessions.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - forward_dead_lettered_messages_to -- Queue/Topic name to forward the Dead Letter message
    - forward_to -- Queue/Topic name to forward the messages
    - lock_duration -- String ISO 8601 timespan or duration format for duration of a peek-lock; that is, the amount of time that the message is locked for other receivers. The maximum value for LockDuration is 5 minutes; the default value is 1 minute.
    - max_delivery_count -- The maximum delivery count. A message is automatically deadlettered after this number of deliveries. default value is 10.
    - max_size -- Maximum size of queue in megabytes, which is the size of the memory allocated for the queue. Default is 1024. Max for Standard SKU is 5120 and for Premium SKU is 81920
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - status -- Enumerates the possible values for the status of a messaging entity.
    '''
    return _call_az("az servicebus queue update", locals())




'''
Get billing invoices for a subscription.
'''
from ... pyaz_utils import _call_az
from . import section


def list(period_end_date, period_start_date, account_name=None, profile_name=None):
    '''
    List the invoices for a subscription.

    Required Parameters:
    - period_end_date -- The end date to fetch the invoices. The date should be specified in MM-DD-YYYY format.
    - period_start_date -- The start date to fetch the invoices. The date should be specified in MM-DD-YYYY format.

    Optional Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - profile_name -- The ID that uniquely identifies a billing profile.
    '''
    return _call_az("az billing invoice list", locals())


def show(name, account_name=None, by_subscription=None):
    '''
    Get an invoice. The operation is supported for billing accounts with agreement type Microsoft Partner Agreement or Microsoft Customer Agreement.

    Required Parameters:
    - name -- The ID that uniquely identifies an invoice.

    Optional Parameters:
    - account_name -- The ID that uniquely identifies a billing account.
    - by_subscription -- When provided, it must work with --invoice-name to get an invoice by subscription ID and invoice ID
    '''
    return _call_az("az billing invoice show", locals())


def download(account_name=None, download_token=None, download_urls=None, invoice_name=None):
    '''
    Get URL to download invoice

    Optional Parameters:
    - account_name -- The ID that uniquely identifies a billing account
    - download_token -- The download token with document source and document ID
    - download_urls -- Space-separated list of download urls for individual
    - invoice_name -- The ID that uniquely identifies an invoice
    '''
    return _call_az("az billing invoice download", locals())




'''
Manage alert with databoxedge
'''
from ... pyaz_utils import _call_az

def list(device_name, resource_group):
    '''
    Get all the alerts for a Data Box Edge/Data Box Gateway device.

    Required Parameters:
    - device_name -- The device name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az databoxedge alert list", locals())


def show(device_name, name, resource_group):
    '''
    Get an alert by name.

    Required Parameters:
    - device_name -- The device name.
    - name -- The alert name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az databoxedge alert show", locals())




'''
Manage Azure Service Bus Namespace
'''
from ... pyaz_utils import _call_az
from . import authorization_rule, network_rule


def create(name, resource_group, capacity=None, default_action=None, location=None, sku=None, tags=None):
    '''
    Create a Service Bus Namespace

    Required Parameters:
    - name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - capacity -- Number of message units. This property is only applicable to namespaces of Premium SKU
    - default_action -- Default action for network rule set.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - sku -- Namespace SKU.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az servicebus namespace create", locals())


def show(name, resource_group):
    '''
    Shows the Service Bus Namespace details

    Required Parameters:
    - name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus namespace show", locals())


def list(resource_group=None):
    '''
    List the Service Bus Namespaces

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus namespace list", locals())


def delete(name, resource_group):
    '''
    Deletes the Service Bus Namespace

    Required Parameters:
    - name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az servicebus namespace delete", locals())


def exists(name):
    '''
    check for the availability of the given name for the Namespace

    Required Parameters:
    - name -- Namespace name. Name can contain only letters, numbers, and hyphens. The namespace must start with a letter, and it must end with a letter or number.
    '''
    return _call_az("az servicebus namespace exists", locals())


def update(name, resource_group, add=None, capacity=None, default_action=None, force_string=None, remove=None, set=None, sku=None, tags=None):
    '''
    Updates a Service Bus Namespace

    Required Parameters:
    - name -- Name of Namespace
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - capacity -- Number of message units. This property is only applicable to namespaces of Premium SKU
    - default_action -- Default action for network rule set.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku -- Namespace SKU.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az servicebus namespace update", locals())




'''
Manage the Skype Channel on a bot.
'''
from ... pyaz_utils import _call_az

def create(name, resource_group, add_disabled=None, calling_web_hook=None, enable_calling=None, enable_groups=None, enable_media_cards=None, enable_messaging=None, enable_screen_sharing=None, enable_video=None, groups_mode=None):
    '''
    Create the Skype Channel on a bot.

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add_disabled -- Add the channel in a disabled state.
    - calling_web_hook -- The calling web hook to use on Skype.
    - enable_calling -- Enable calling on Skype.
    - enable_groups -- Enable groups on Skype.
    - enable_media_cards -- Enable media cards on Skype.
    - enable_messaging -- Enable messaging on Skype.
    - enable_screen_sharing -- Enable screen sharing on Skype.
    - enable_video -- Enable video on Skype.
    - groups_mode -- select groups mode on Skype.
    '''
    return _call_az("az bot skype create", locals())


def show(name, resource_group, with_secrets=None):
    '''
    Get details of the Skype Channel on a bot

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - with_secrets -- Show secrets in response for the channel.
    '''
    return _call_az("az bot skype show", locals())


def delete(name, resource_group):
    '''
    Delete the Skype Channel on a bot

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az bot skype delete", locals())




'''
Manage Data Lake Analytics job pipelines.
'''
from .... pyaz_utils import _call_az

def show(account, pipeline_identity, end_date_time=None, start_date_time=None):
    '''
    Retrieve a job pipeline in a Data Lake Analytics account.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.
    - pipeline_identity -- Pipeline ID.

    Optional Parameters:
    - end_date_time -- The end date for when to get the pipeline and aggregate its data. The startDateTime and endDateTime can be no more than 30 days apart.
    - start_date_time -- The start date for when to get the pipeline and aggregate its data. The startDateTime and endDateTime can be no more than 30 days apart.
    '''
    return _call_az("az dla job pipeline show", locals())


def list(account, end_date_time=None, start_date_time=None):
    '''
    List job pipelines in a Data Lake Analytics account.

    Required Parameters:
    - account -- Name of the Data Lake Analytics account.

    Optional Parameters:
    - end_date_time -- The end date for when to get the list of pipelines. The startDateTime and endDateTime can be no more than 30 days apart.
    - start_date_time -- The start date for when to get the list of pipelines. The startDateTime and endDateTime can be no more than 30 days apart.
    '''
    return _call_az("az dla job pipeline list", locals())




'''
Manage SQL pools.
'''
from .... pyaz_utils import _call_az
from . import audit_policy, classification, tde, threat_policy


def show(name, resource_group, workspace_name):
    '''
    Get a SQL pool.

    Required Parameters:
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql pool show", locals())


def list(resource_group, workspace_name):
    '''
    List all SQL pools.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql pool list", locals())


def create(name, performance_level, resource_group, workspace_name, no_wait=None, tags=None):
    '''
    Create a SQL pool.

    Required Parameters:
    - name -- The SQL pool name.
    - performance_level -- The performance level.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az synapse sql pool create", locals())


def delete(name, resource_group, workspace_name, no_wait=None, yes=None):
    '''
    Delete a SQL pool.

    Required Parameters:
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse sql pool delete", locals())


def update(name, resource_group, workspace_name, performance_level=None, tags=None):
    '''
    Update a SQL pool.

    Required Parameters:
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - performance_level -- The performance level.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az synapse sql pool update", locals())


def pause(name, resource_group, workspace_name):
    '''
    Pause a SQL pool.

    Required Parameters:
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql pool pause", locals())


def resume(name, resource_group, workspace_name):
    '''
    Resume a SQL pool.

    Required Parameters:
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql pool resume", locals())


def restore(dest_name, name, resource_group, workspace_name, deleted_time=None, performance_level=None, time=None):
    '''
    Create a new SQL pool by restoring from a backup.

    Required Parameters:
    - dest_name -- Name of the sql pool that will be created as the restore destination.
    - name -- The SQL pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.

    Optional Parameters:
    - deleted_time -- If specified, restore from a deleted database instead of from an existing database. Must match the deleted time of a deleted database in the same server. Either --time or --deleted-time (or both) must be specified. Time should be in following format: "YYYY-MM-DDTHH:MM:SS".
    - performance_level -- The performance level.
    - time -- The point in time of the source database that will be restored to create the new database. Must be greater than or equal to the source database's earliestRestoreDate value. Either --time or --deleted-time (or both) must be specified. Time should be in following format: "YYYY-MM-DDTHH:MM:SS".
    '''
    return _call_az("az synapse sql pool restore", locals())


def show_connection_string(client, auth_type=None, name=None, workspace_name=None):
    '''
    Generate a connection string to a SQL pool.

    Required Parameters:
    - client -- Type of client connection provider.

    Optional Parameters:
    - auth_type -- Type of authentication.
    - name -- The SQL pool name.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql pool show-connection-string", locals())


def wait(resource_group, sql_pool_name, workspace_name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a SQL pool is met.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sql_pool_name -- SQL pool name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az synapse sql pool wait", locals())


def list_deleted(resource_group, workspace_name):
    '''
    List all deleted SQL pools.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse sql pool list-deleted", locals())




'''
Commands to manage node pools in Kubernetes kubernetes cluster.
'''
from ... pyaz_utils import _call_az

def list(cluster_name, resource_group):
    '''
    List node pools in the managed Kubernetes cluster.

    Required Parameters:
    - cluster_name -- The cluster name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az aks nodepool list", locals())


def show(cluster_name, name, resource_group):
    '''
    Show the details for a node pool in the managed Kubernetes cluster.

    Required Parameters:
    - cluster_name -- The cluster name.
    - name -- The node pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az aks nodepool show", locals())


def add(cluster_name, name, resource_group, enable_cluster_autoscaler=None, enable_encryption_at_host=None, enable_node_public_ip=None, enable_ultra_ssd=None, eviction_policy=None, kubernetes_version=None, labels=None, max_count=None, max_pods=None, max_surge=None, min_count=None, mode=None, no_wait=None, node_count=None, node_osdisk_size=None, node_osdisk_type=None, node_public_ip_prefix_id=None, node_taints=None, node_vm_size=None, os_sku=None, os_type=None, ppg=None, priority=None, spot_max_price=None, tags=None, vnet_subnet_id=None, zones=None):
    '''
    Add a node pool to the managed Kubernetes cluster.

    Required Parameters:
    - cluster_name -- The cluster name.
    - name -- The node pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - enable_cluster_autoscaler -- None
    - enable_encryption_at_host -- None
    - enable_node_public_ip -- None
    - enable_ultra_ssd -- None
    - eviction_policy -- None
    - kubernetes_version -- None
    - labels -- None
    - max_count -- None
    - max_pods -- None
    - max_surge -- None
    - min_count -- None
    - mode -- None
    - no_wait -- Do not wait for the long-running operation to finish.
    - node_count -- None
    - node_osdisk_size -- None
    - node_osdisk_type -- None
    - node_public_ip_prefix_id -- None
    - node_taints -- None
    - node_vm_size -- None
    - os_sku -- None
    - os_type -- None
    - ppg -- None
    - priority -- None
    - spot_max_price -- None
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vnet_subnet_id -- None
    - zones -- Space-separated list of availability zones where agent nodes will be placed.
    '''
    return _call_az("az aks nodepool add", locals())


def scale(cluster_name, name, resource_group, no_wait=None, node_count=None):
    '''
    Scale the node pool in a managed Kubernetes cluster.

    Required Parameters:
    - cluster_name -- The cluster name.
    - name -- The node pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - node_count -- None
    '''
    return _call_az("az aks nodepool scale", locals())


def upgrade(cluster_name, name, resource_group, kubernetes_version=None, max_surge=None, no_wait=None, node_image_only=None):
    '''
    Upgrade the node pool in a managed Kubernetes cluster.

    Required Parameters:
    - cluster_name -- The cluster name.
    - name -- The node pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - kubernetes_version -- None
    - max_surge -- None
    - no_wait -- Do not wait for the long-running operation to finish.
    - node_image_only -- None
    '''
    return _call_az("az aks nodepool upgrade", locals())


def update(cluster_name, name, resource_group, disable_cluster_autoscaler=None, enable_cluster_autoscaler=None, labels=None, max_count=None, max_surge=None, min_count=None, mode=None, no_wait=None, tags=None, update_cluster_autoscaler=None):
    '''
    Update a node pool to enable/disable cluster-autoscaler or change min-count or max-count

    Required Parameters:
    - cluster_name -- The cluster name.
    - name -- The node pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - disable_cluster_autoscaler -- None
    - enable_cluster_autoscaler -- None
    - labels -- None
    - max_count -- None
    - max_surge -- None
    - min_count -- None
    - mode -- None
    - no_wait -- Do not wait for the long-running operation to finish.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - update_cluster_autoscaler -- None
    '''
    return _call_az("az aks nodepool update", locals())


def delete(cluster_name, name, resource_group, no_wait=None):
    '''
    Delete the agent pool in the managed Kubernetes cluster.

    Required Parameters:
    - cluster_name -- The cluster name.
    - name -- The node pool name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az aks nodepool delete", locals())


def get_upgrades(cluster_name, nodepool_name, resource_group):
    '''
    Get the available upgrade versions for an agent pool of the managed Kubernetes cluster.

    Required Parameters:
    - cluster_name -- The cluster name.
    - nodepool_name -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az aks nodepool get-upgrades", locals())




'''
Manage deployment operations at management group.
'''
from .... pyaz_utils import _call_az

def list(management_group_id, name):
    '''
    List deployment operations at management group.

    Required Parameters:
    - management_group_id -- The management group id.
    - name -- The deployment name.
    '''
    return _call_az("az deployment operation mg list", locals())


def show(management_group_id, name, operation_ids):
    '''
    Show a deployment operation at management group.

    Required Parameters:
    - management_group_id -- The management group id.
    - name -- The deployment name.
    - operation_ids -- A list of operation ids to show
    '''
    return _call_az("az deployment operation mg show", locals())




'''
Tag Management on a resource.
'''
from .. pyaz_utils import _call_az

def list(resource_id=None):
    '''
    List the entire set of tags on a specific resource.

    Optional Parameters:
    - resource_id -- The resource identifier for the tagged entity. A resource, a resource group or a subscription may be tagged.
    '''
    return _call_az("az tag list", locals())


def create(name=None, resource_id=None, tags=None):
    '''
    Create tags on a specific resource.

    Optional Parameters:
    - name -- The tag name.
    - resource_id -- The resource identifier for the tagged entity. A resource, a resource group or a subscription may be tagged.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az tag create", locals())


def delete(name=None, resource_id=None, yes=None):
    '''
    Delete tags on a specific resource.

    Optional Parameters:
    - name -- The tag name.
    - resource_id -- The resource identifier for the tagged entity. A resource, a resource group or a subscription may be tagged.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az tag delete", locals())


def update(operation, resource_id, tags):
    '''
    Selectively update the set of tags on a specific resource.

    Required Parameters:
    - operation -- The update operation: options include Merge, Replace and Delete.
    - resource_id -- The resource identifier for the tagged entity. A resource, a resource group or a subscription may be tagged.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az tag update", locals())


def add_value(name, value):
    '''
    Create a tag value.

    Required Parameters:
    - name -- The tag name.
    - value -- The tag value.
    '''
    return _call_az("az tag add-value", locals())


def remove_value(name, value):
    '''
    

    Required Parameters:
    - name -- The tag name.
    - value -- The tag value.
    '''
    return _call_az("az tag remove-value", locals())




'''
Managed Service Identities
'''
from .. pyaz_utils import _call_az

def create(name, resource_group, location=None, tags=None):
    '''
    

    Required Parameters:
    - name -- The name of the identity resource.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az identity create", locals())


def show(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The name of the identity resource.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az identity show", locals())


def delete(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The name of the identity resource.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az identity delete", locals())


def list(resource_group=None):
    '''
    List Managed Service Identities

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az identity list", locals())


def list_operations():
    '''
    Lists available operations for the Managed Identity provider
    '''
    return _call_az("az identity list-operations", locals())

